import { useState, useEffect } from "react";
import { getLocations } from "../../../mock-api/apis.js";
import "./LocationInput.css";
import { Subject } from "rxjs";

// Fetches location options on mount
// Shares currently selected location with any listeners (anywhere!)
// Finite number of renders -> no pass by props re-rendering
export default function LocationInput() {
  const [options, setOptions] = useState([]);

  // on component mount (Only runs once!)
  useEffect(() => {
    // Fetch selectable locations
    getLocations().then((locations) => {
      // push the first location to the selectedLocation subject
      // This is how we share the selected location with listeners
      selectedLocation.next(locations[0]);

      // Render the location options and save to state for re-render
      // Options are static -> no need to re-render after this.
      setOptions(
        locations.map((option) => {
          return (
            <option key={option} value={option}>
              {option}
            </option>
          );
        }),
      );
    });
  }, []);

  return (
    <div className="LocationInput">
      <label htmlFor="location">Location</label>
      <select
        name="location"
        id="location"
        onChange={(e) => {
          // Push new location to listeners
          selectedLocation.next(e.target.value);
        }}
      >
        {options}
      </select>
    </div>
  );
}

export const selectedLocation = new Subject();
